# All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

import ddt
import mock

from rally.plugins.openstack.scenarios.monasca import metrics
from tests.unit import test


@ddt.ddt
class MonascaMetricsTestCase(test.ScenarioTestCase):

    @ddt.data(
        {"region": None},
        {"region": "fake_region"},
    )
    @ddt.unpack
    def test_list_metrics(self, region=None):
        scenario = metrics.ListMetrics(self.context)
        self.region = region
        scenario._list_metrics = mock.MagicMock()
        scenario.run(region=self.region)
        scenario._list_metrics.assert_called_once_with(region=self.region)
